EKF SQ1-TRACK — ekfsm documentation

# EKF SQ1-TRACK

## Inventory

The inventory function provides access to the inventory, such as the vendor, model, serial number (taken from the board’s EEPROM), and revision (from the board’s GPIO device).

Method | Description | Example Value
`vendor()` | Get the board vendor | `EKF`
`model()` | Get the board model | `SUR-UART`
`serial()` | Get the board serial number | `12345678`
`revision()` | Get the board revision | `1`